<?php
/**
 * Theme functions and definitions
 *
 * @package tv_channel_insight
 */ 

if ( ! function_exists( 'tv_channel_insight_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function tv_channel_insight_enqueue_styles() {
		wp_enqueue_style( 'cyber-security-services-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'tv-channel-insight-style', get_stylesheet_directory_uri() . '/style.css', array( 'cyber-security-services-style-parent' ), '1.0.0' );
		// Theme Customize CSS.
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'tv-channel-insight-style',$cyber_security_services_custom_style );
	}
endif;
add_action( 'wp_enqueue_scripts', 'tv_channel_insight_enqueue_styles', 99 );

function tv_channel_insight_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'tv-channel-insight-featured-image', 2000, 1200, true );
	add_image_size( 'tv-channel-insight-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'tv-channel-insight' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}
add_action( 'after_setup_theme', 'tv_channel_insight_setup' );

function tv_channel_insight_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'tv-channel-insight' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'tv-channel-insight' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'tv-channel-insight' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'tv-channel-insight' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'tv-channel-insight' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'tv-channel-insight' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Product Category Dropdown', 'tv-channel-insight' ),
		'id'            => 'product-cat',
		'description'   => __( 'Add widgets here to appear in your header.', 'tv-channel-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'tv_channel_insight_widgets_init' );

function tv_channel_insight_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'cyber_security_services_pro' );
	$wp_customize->remove_section( 'cyber_security_services_product_box_section' );
}
add_action( 'customize_register', 'tv_channel_insight_customize_register', 11 );

function tv_channel_insight_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	$wp_customize->add_section('tv_channel_insight_pro', array(
		'title'    => __('UPGRADE TV CHANNEL PREMIUM', 'tv-channel-insight'),
		'priority' => 1,
	));

	$wp_customize->add_setting('tv_channel_insight_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new TV_Channel_Insight_Pro_Control($wp_customize, 'tv_channel_insight_pro', array(
		'label'    => __('TV CHANNEL INSIGHT PREMIUM', 'tv-channel-insight'),
		'section'  => 'tv_channel_insight_pro',
		'settings' => 'tv_channel_insight_pro',
		'priority' => 1,
	)));

	// Services Section
	$wp_customize->add_section( 'tv_channel_insight_middle_section' , array(
    	'title'      => __( 'Services Settings', 'tv-channel-insight' ),
		'priority'   => 6,
	) );

	$wp_customize->add_setting('tv_channel_insight_middle_heading',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('tv_channel_insight_middle_heading',array(
		'label' => esc_html__('Heading','tv-channel-insight'),
		'section' => 'tv_channel_insight_middle_section',
		'setting' => 'tv_channel_insight_middle_heading',
		'type'    => 'text'
	));

	$wp_customize->add_setting('tv_channel_insight_middle_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('tv_channel_insight_middle_title',array(
		'label' => esc_html__('Title','tv-channel-insight'),
		'section' => 'tv_channel_insight_middle_section',
		'setting' => 'tv_channel_insight_middle_title',
		'type'    => 'text'
	));

	$tv_channel_insight_args = array('numberposts' => -1);
	$tv_channel_insight_post_list = get_posts($tv_channel_insight_args);
	$s = 0;
	$tv_channel_insight_pst_sls[]= __('Select','tv-channel-insight');
	foreach ($tv_channel_insight_post_list as $key => $tv_channel_insight_p_post) {
		$tv_channel_insight_pst_sls[$tv_channel_insight_p_post->ID]=$tv_channel_insight_p_post->post_title;
	}
	for ( $s = 1; $s <= 6; $s++ ) {
		$wp_customize->add_setting('tv_channel_insight_mid_section_icon'.$s,array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field'
		));
		$wp_customize->add_control('tv_channel_insight_mid_section_icon'.$s,array(
			'label' => esc_html__('Icon','tv-channel-insight'),
			'description' => esc_html__('Add the fontawesome class to add icon ex: fas fa-envelope','tv-channel-insight'),
			'section' => 'tv_channel_insight_middle_section',
			'setting' => 'tv_channel_insight_mid_section_icon',
			'type'    => 'text'
		));

		$wp_customize->add_setting('tv_channel_insight_middle_sec_settigs'.$s,array(
			'sanitize_callback' => 'cyber_security_services_sanitize_choices',
		));
		$wp_customize->add_control('tv_channel_insight_middle_sec_settigs'.$s,array(
			'type'    => 'select',
			'choices' => $tv_channel_insight_pst_sls,
			'label' => __('Select post','tv-channel-insight'),
			'section' => 'tv_channel_insight_middle_section',
		));
	}
	wp_reset_postdata();
}
add_action( 'customize_register', 'tv_channel_insight_customize' );

function tv_channel_insight_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action('wp_enqueue_scripts', 'tv_channel_insight_enqueue_comments_reply');

if ( ! defined( 'TV_CHANNEL_INSIGHT_PRO_LINK' ) ) {
	define('TV_CHANNEL_INSIGHT_PRO_LINK',__('https://www.ovationthemes.com/wordpress/wordpress-tv-channel-theme/','tv-channel-insight'));
}

if ( ! defined( 'CYBER_SECURITY_SERVICES_SUPPORT' ) ) {
define('CYBER_SECURITY_SERVICES_SUPPORT',__('https://wordpress.org/support/theme/tv-channel-insight','tv-channel-insight'));
}
if ( ! defined( 'CYBER_SECURITY_SERVICES_REVIEW' ) ) {
define('CYBER_SECURITY_SERVICES_REVIEW',__('https://wordpress.org/support/theme/tv-channel-insight/reviews/','tv-channel-insight'));
}
if ( ! defined( 'CYBER_SECURITY_SERVICES_LIVE_DEMO' ) ) {
define('CYBER_SECURITY_SERVICES_LIVE_DEMO',__('https://www.ovationthemes.com/demos/tv-channel-insight/','tv-channel-insight'));
}
if ( ! defined( 'CYBER_SECURITY_SERVICES_BUY_PRO' ) ) {
define('CYBER_SECURITY_SERVICES_BUY_PRO',__('https://www.ovationthemes.com/wordpress/wordpress-tv-channel-theme/','tv-channel-insight'));
}
if ( ! defined( 'CYBER_SECURITY_SERVICES_PRO_DOC' ) ) {
define('CYBER_SECURITY_SERVICES_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-tv-channel-insight-pro-doc','tv-channel-insight'));
}
if ( ! defined( 'CYBER_SECURITY_SERVICES_THEME_NAME' ) ) {
define('CYBER_SECURITY_SERVICES_THEME_NAME',__('Premium TV Channel Insight Theme','tv-channel-insight'));
}


/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('TV_Channel_Insight_Pro_Control')):
    class TV_Channel_Insight_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( TV_CHANNEL_INSIGHT_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE TV CHANNEL PREMIUM','tv-channel-insight');?> </a>
            </div>
            <div class="col-md">
                <img class="tv_channel_insight_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('TV CHANNEL PREMIUM - Features', 'tv-channel-insight'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'tv-channel-insight');?> </li>
                    <li class="upsell-tv_channel_insight"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'tv-channel-insight');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( TV_CHANNEL_INSIGHT_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE TV CHANNEL PREMIUM','tv-channel-insight');?> </a>
            </div>
        </label>
    <?php } }
endif;